==> scilab_5.4.1.orig.tar.gz: scilab-5.4.1/modules/graphics/src/c/getHandleProperty/get_x_shift_property.c <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2004-2006 - INRIA - Fabrice Leray
 * Copyright (C) 2006 - INRIA - Allan Cornet
 * Copyright (C) 2006 - INRIA - Jean-Baptiste Silvy
 * Copyright (C) 2010 - DIGITEO - Manuel Juliachs
 * Copyright (C) 2011 - DIGITEO - Vincent Couvert
 *
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

/*------------------------------------------------------------------------*/
/* file: get_x_shift_property.c                                           */
/* desc : function to retrieve in Scilab the x_shift field of a           */
/*        handle                                                          */
/*------------------------------------------------------------------------*/

#include "getHandleProperty.h"
#include "GetProperty.h"
#include "returnProperty.h"
#include "Scierror.h"
#include "localization.h"
#include "MALLOC.h"

#include "getGraphicObjectProperty.h"
#include "graphicObjectProperties.h"

/*------------------------------------------------------------------------*/
int get_x_shift_property(void* _pvCtx, char* pobjUID)
{
    double* shiftCoordinates = NULL;
    int iValue = 0;
    int* piValue = &iValue;

    getGraphicObjectProperty(pobjUID, __GO_DATA_MODEL_X_COORDINATES_SHIFT_SET__, jni_int, (void**)&piValue);

    if (piValue == NULL)
    {
        Scierror(999, _("'%s' property does not exist for this handle.\n"),"x_shift");
        return -1;
    }

    if (iValue == 0)
    {
        return sciReturnEmptyMatrix(_pvCtx);
    }
    else
    {
        getGraphicObjectProperty(pobjUID, __GO_DATA_MODEL_X_COORDINATES_SHIFT__, jni_double_vector, (void **)&shiftCoordinates);
        getGraphicObjectProperty(pobjUID, __GO_DATA_MODEL_NUM_ELEMENTS__, jni_int, (void**)&piValue);

        return sciReturnRowVector(_pvCtx, shiftCoordinates, iValue);
    }
}
/*------------------------------------------------------------------------*/

==> scilab_5.5.2.orig.tar.gz: scilab-5.5.2/modules/graphics/src/c/getHandleProperty/get_x_shift_property.c <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2004-2006 - INRIA - Fabrice Leray
 * Copyright (C) 2006 - INRIA - Allan Cornet
 * Copyright (C) 2006 - INRIA - Jean-Baptiste Silvy
 * Copyright (C) 2010 - DIGITEO - Manuel Juliachs
 * Copyright (C) 2011 - DIGITEO - Vincent Couvert
 *
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at
 * http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
 *
 */

/*------------------------------------------------------------------------*/
/* file: get_x_shift_property.c                                           */
/* desc : function to retrieve in Scilab the x_shift field of a           */
/*        handle                                                          */
/*------------------------------------------------------------------------*/

#include "getHandleProperty.h"
#include "GetProperty.h"
#include "returnProperty.h"
#include "Scierror.h"
#include "localization.h"
#include "MALLOC.h"

#include "getGraphicObjectProperty.h"
#include "graphicObjectProperties.h"

/*------------------------------------------------------------------------*/
int get_x_shift_property(void* _pvCtx, int iObjUID)
{
    double* shiftCoordinates = NULL;
    int iValue = 0;
    int* piValue = &iValue;

    getGraphicObjectProperty(iObjUID, __GO_DATA_MODEL_X_COORDINATES_SHIFT_SET__, jni_int, (void**)&piValue);

    if (piValue == NULL)
    {
        Scierror(999, _("'%s' property does not exist for this handle.\n"), "x_shift");
        return -1;
    }

    if (iValue == 0)
    {
        return sciReturnEmptyMatrix(_pvCtx);
    }
    else
    {
        getGraphicObjectProperty(iObjUID, __GO_DATA_MODEL_X_COORDINATES_SHIFT__, jni_double_vector, (void **)&shiftCoordinates);
        getGraphicObjectProperty(iObjUID, __GO_DATA_MODEL_NUM_ELEMENTS__, jni_int, (void**)&piValue);

        return sciReturnRowVector(_pvCtx, shiftCoordinates, iValue);
    }
}
/*------------------------------------------------------------------------*/
